{% extends "organizations_base.html" %}
{% load url from future %}
{% block content %}
  <h1 id="login-header">Log in to your dashboard</h1>
  <div id="login-box">
    <form method="post" action="{% url login %}">{% csrf_token %}
        {{ form }}
        <input type="submit" value="Login">
    </form>
    <p>Forgotten your password? <a href="{% url "password_reset" %}">Reset it.</a></p>
  </div>
{% endblock %}

