{% load url from future %}

You've been invited to join {{ organization|safe }} on {{ domain.name }} by {{ sender.first_name|safe }} {{ sender.last_name|safe }}.

Follow this link to create your user account.

http://{{ domain.domain }}{% url "invitations_register" user.id token %}

If you are unsure about this link please contact the sender.
